@@ -2,7 +2,7 @@ import asyncio
 import ipaddress
 import re
 import socket
-from typing import Tuple, Generator, Union
+from typing import Tuple, Generator, Union, Optional
 from contextlib import contextmanager, asynccontextmanager
 
 from python_socks.sync import Proxy
@@ -19,9 +19,15 @@ class Query:
     refer_regex = r"refer: *(.+)"
     whois_server_regex = r".+ whois server: *(.+)"
 
-    def __init__(self, proxy_url: str = None, timeout: int = 10):
+    def __init__(
+        self,
+        proxy_url: Optional[str] = None,
+        timeout: int = 10,
+        find_authoritative_server: bool = True,
+    ):
         self.proxy_url = proxy_url
         self.timeout = timeout
+        self.find_authoritative_server = find_authoritative_server
 
     @staticmethod
     def _find_match(regex: str, blob: str) -> str:
@@ -33,7 +39,7 @@ class Query:
 
     @contextmanager
     def _create_connection(
-        self, address: Tuple[str, int], proxy_url: str = None
+        self, address: Tuple[str, int], proxy_url: Optional[str] = None
     ) -> Generator[socket.socket, None, None]:
         s = None
         try:
@@ -52,7 +58,7 @@ class Query:
 
     @asynccontextmanager
     async def _aio_create_connection(
-        self, address: Tuple[str, int], proxy_url: str = None
+        self, address: Tuple[str, int], proxy_url: Optional[str] = None
     ) -> Generator[Tuple[asyncio.StreamReader, asyncio.StreamWriter], None, None]:
         # init
         reader, writer = None, None
@@ -101,7 +107,7 @@ class Query:
                 result += received.decode("utf-8", errors="ignore")
         return result
 
-    def run(self, search_term: str, server: str = None) -> list[str]:
+    def run(self, search_term: str, server: Optional[str] = None) -> list[str]:
         """
         Submits the `search_term` to the WHOIS server and returns a list of query responses.
         """
@@ -117,7 +123,19 @@ class Query:
             server_regex = self.whois_server_regex
         return self._do_query(server, data, server_regex, [])
 
-    async def aio_run(self, search_term: str, server: str = None) -> list[str]:
+    @staticmethod
+    def _continue_querying(current_server: str, next_server: str) -> bool:
+        next_server = next_server.lower()
+        return (
+            next_server
+            and next_server != current_server
+            and not next_server.startswith("http")
+            and not next_server.startswith("www.")
+        )
+
+    async def aio_run(
+        self, search_term: str, server: Optional[str] = None
+    ) -> list[str]:
         data = search_term + "\r\n"
         if not server:
             if ":" in data:  # ipv6
@@ -141,18 +159,16 @@ class Query:
             query_output = self._send_and_recv(conn, data)
             # save query chain
             chain.append(query_output)
-            # parse response for the referred WHOIS server name
-            whois_server = self._find_match(regex, query_output)
-            whois_server = whois_server.lower()
-            if (
-                whois_server
-                and whois_server != server
-                and not whois_server.startswith("http")
-            ):
-                # recursive call to find more authoritative server
-                chain = self._do_query(
-                    whois_server, data, self.whois_server_regex, chain
-                )
+            # if we should find the authoritative response,
+            # then parse the response for the next server
+            if self.find_authoritative_server:
+                # parse response for the referred WHOIS server name
+                whois_server = self._find_match(regex, query_output)
+                if self._continue_querying(server, whois_server):
+                    # recursive call to find more authoritative server
+                    chain = self._do_query(
+                        whois_server, data, self.whois_server_regex, chain
+                    )
         # return the WHOIS query chain
         return chain
 
@@ -170,18 +186,16 @@ class Query:
                 self._aio_send_and_recv(reader, writer, data), self.timeout
             )
             chain.append(query_output)
-            # parse response for the referred WHOIS server name
-            whois_server = self._find_match(regex, query_output)
-            whois_server = whois_server.lower()
-            if (
-                whois_server
-                and whois_server != server
-                and not whois_server.startswith("http")
-            ):
-                # recursive call to find the authoritative server
-                chain = await self._aio_do_query(
-                    whois_server, data, self.whois_server_regex, chain
-                )
+            # if we should find the authoritative response,
+            # then parse the response for the next server
+            if self.find_authoritative_server:
+                # parse response for the referred WHOIS server name
+                whois_server = self._find_match(regex, query_output)
+                if self._continue_querying(server, whois_server):
+                    # recursive call to find more authoritative server
+                    chain = await self._aio_do_query(
+                        whois_server, data, self.whois_server_regex, chain
+                    )
         # return the WHOIS query chain
         return chain
 
@@ -189,15 +203,17 @@ class Query:
 class DomainQuery(Query):
     def __init__(
         self,
-        server: str = None,
-        proxy_url: str = None,
+        server: Optional[str] = None,
+        proxy_url: Optional[str] = None,
         timeout: int = 10,
+        find_authoritative_server: bool = True,
     ):
-        super().__init__(proxy_url, timeout)
+        super().__init__(proxy_url, timeout, find_authoritative_server)
         self.server = server
 
     @staticmethod
-    def _get_server_name(tld: str) -> Union[str, None]:
+    def _get_server_name(domain_name: str) -> Union[str, None]:
+        tld = domain_name.split(".")[-1]
         tld_converted = tld.upper().replace("-", "_")
         for servers in [CountryCodeTLD, GenericTLD, SponsoredTLD]:
             if hasattr(servers, tld_converted):
@@ -205,12 +221,14 @@ class DomainQuery(Query):
                 return server
         return None
 
-    def run(self, search_term: str, server: str = None) -> list[str]:
+    def run(self, search_term: str, server: Optional[str] = None) -> list[str]:
         if not server:
             server = self._get_server_name(search_term)
         return super().run(str(search_term), server)
 
-    async def aio_run(self, search_term: str, server: str = None) -> list[str]:
+    async def aio_run(
+        self, search_term: str, server: Optional[str] = None
+    ) -> list[str]:
         if not server:
             server = self._get_server_name(search_term)
         return await super().aio_run(str(search_term), server)
@@ -219,8 +237,8 @@ class DomainQuery(Query):
 class NumberQuery(Query):
     def __init__(
         self,
-        server: str = None,
-        proxy_url: str = None,
+        server: Optional[str] = None,
+        proxy_url: Optional[str] = None,
         timeout: int = 10,
     ):
         super().__init__(proxy_url, timeout)
@@ -238,7 +256,7 @@ class NumberQuery(Query):
     def run(
         self,
         search_term: Union[ipaddress.IPv4Address, ipaddress.IPv6Address],
-        server: str = None,
+        server: Optional[str] = None,
     ) -> list[str]:
         if not server:
             server = self._get_server_name(search_term)
@@ -247,7 +265,7 @@ class NumberQuery(Query):
     async def aio_run(
         self,
         search_term: Union[ipaddress.IPv4Address, ipaddress.IPv6Address],
-        server: str = None,
+        server: Optional[str] = None,
     ) -> list[str]:
         if not server:
             server = self._get_server_name(search_term)
